Module build

Module build 

Structs

Build
Everything required to configure and run the wasm-js build command.
BuildOptions
Everything required to configure and run the build command.

Enums

BuildProfile
The build profile controls whether optimizations, debug info, and assertions are enabled or disabled.