pub struct BuildOptions {Show 13 fields
pub path: Option<PathBuf>,
pub mode: InstallMode,
pub weak_refs: bool,
pub reference_types: bool,
pub debug: bool,
pub dev: bool,
pub release: bool,
pub profiling: bool,
pub profile: Option<String>,
pub out_dir: String,
pub out_name: Option<String>,
pub no_opt: bool,
pub extra_options: Vec<String>,
}Expand description
Everything required to configure and run the build command.
Fields
path: Option<PathBuf>The path to the Rust crate. If not set, searches up the path from the current directory.
mode: InstallModeSets steps to be run. [possible values: no-install, normal, force]
weak_refs: boolEnable usage of the JS weak references proposal.
reference_types: boolEnable usage of WebAssembly reference types.
debug: boolDeprecated. Renamed to --dev.
dev: boolCreate a development build. Enable debug info, and disable optimizations.
release: boolCreate a release build. Enable optimizations and disable debug info.
profiling: boolCreate a profiling build. Enable optimizations and debug info.
profile: Option<String>User-defined profile with –profile flag
out_dir: StringSets the output directory with a relative path.
out_name: Option<String>Sets the output file names. Defaults to package name.
no_opt: boolOption to skip optimization with wasm-opt
extra_options: Vec<String>List of extra options to pass to cargo build