Utility functions for commands.
Traits
Functions
- create_
output_ dir - Construct our
distdirectory in the crate. - elapsed
- Render a
Durationto a form suitable for display on a console - get_
crate_ path - If an explicit path is given, then use it, otherwise assume the current directory is the crate path.
- get_
install_ cache - Get wasm-pack’s binary cache.
- read_
and_ compress - Reads a file from
input_pathand returns its contents compressed using DEFLATE as an in-memory vector of bytes (Vec<u8>).